==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/b7/b7880bd56f1d4c66222f2331219fe01a.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/EmailBundle/Event/EmailStatEvent.php */
class __TwigTemplate_515bdff19c2d18dbf58dc8c851c796b9 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\EmailBundle\\Event;

use Mautic\\EmailBundle\\Entity\\Stat;
use Symfony\\Contracts\\EventDispatcher\\Event;

final class EmailStatEvent extends Event
{
    /**
     * @param Stat[] \$stats
     */
    public function __construct(
        private array \$stats
    ) {
    }

    /**
     * @return Stat[]
     */
    public function getStats(): array
    {
        return \$this->stats;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/EmailBundle/Event/EmailStatEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/EmailBundle/Event/EmailStatEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Event/EmailStatEvent.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/b7/b7880bd56f1d4c66222f2331219fe01a.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/EmailBundle/Event/EmailStatEvent.php */
class __TwigTemplate_515bdff19c2d18dbf58dc8c851c796b9 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\EmailBundle\\Event;

use Mautic\\EmailBundle\\Entity\\Stat;
use Symfony\\Contracts\\EventDispatcher\\Event;

final class EmailStatEvent extends Event
{
    /**
     * @param Stat[] \$stats
     */
    public function __construct(
        private array \$stats
    ) {
    }

    /**
     * @return Stat[]
     */
    public function getStats(): array
    {
        return \$this->stats;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/EmailBundle/Event/EmailStatEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/EmailBundle/Event/EmailStatEvent.php", "/var/www/html/production-demo/app/bundles/EmailBundle/Event/EmailStatEvent.php");
    }
}
